summaryrefslogtreecommitdiffstats
path: root/kicker/libkicker
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:43:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:43:14 -0600
commit79b21d47bce1ee428affc97534cd8b257232a871 (patch)
tree0df1fa0109d9f2bcef932eda8b5c25b2e06669ed /kicker/libkicker
parent9a898d493f493adbc404f7223043c85f3817472b (diff)
downloadtdebase-79b21d47bce1ee428affc97534cd8b257232a871.tar.gz
tdebase-79b21d47bce1ee428affc97534cd8b257232a871.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kicker/libkicker')
-rw-r--r--kicker/libkicker/global.cpp8
-rw-r--r--kicker/libkicker/kickerSettings.kcfg4
-rw-r--r--kicker/libkicker/panelbutton.cpp16
-rw-r--r--kicker/libkicker/panner.cpp2
-rw-r--r--kicker/libkicker/simplebutton.cpp2
5 files changed, 16 insertions, 16 deletions
diff --git a/kicker/libkicker/global.cpp b/kicker/libkicker/global.cpp
index d4735c2ba..0527f8224 100644
--- a/kicker/libkicker/global.cpp
+++ b/kicker/libkicker/global.cpp
@@ -326,7 +326,7 @@ TQPoint popupPosition(KPanelApplet::Direction d,
void colorize(TQImage& image)
{
- KConfig *config = KGlobal::config();
+ KConfig *config = TDEGlobal::config();
config->setGroup("WM");
TQColor color = TQApplication::palette().active().highlight();
TQColor activeTitle = config->readColorEntry("activeBackground", &color);
@@ -414,20 +414,20 @@ TQIconSet menuIconSet(const TQString& icon)
{
if (iconSize > 0)
{
- iconset = KGlobal::iconLoader()->loadIconSet(icon,
+ iconset = TDEGlobal::iconLoader()->loadIconSet(icon,
KIcon::NoGroup,
iconSize, true);
}
else if (iconSize == 0)
{
- TQPixmap normal = KGlobal::iconLoader()->loadIcon(icon,
+ TQPixmap normal = TDEGlobal::iconLoader()->loadIcon(icon,
KIcon::Small,
0,
KIcon::DefaultState,
0,
true);
- TQPixmap active = KGlobal::iconLoader()->loadIcon(icon,
+ TQPixmap active = TDEGlobal::iconLoader()->loadIcon(icon,
KIcon::Small,
0,
KIcon::ActiveState,
diff --git a/kicker/libkicker/kickerSettings.kcfg b/kicker/libkicker/kickerSettings.kcfg
index 9a4abc7fc..fcc14f71e 100644
--- a/kicker/libkicker/kickerSettings.kcfg
+++ b/kicker/libkicker/kickerSettings.kcfg
@@ -441,12 +441,12 @@
<entry name="ButtonFont" key="Font" type="Font" >
<label>Font for the buttons with text.</label>
- <default code="true">KGlobalSettings::generalFont()</default>
+ <default code="true">TDEGlobalSettings::generalFont()</default>
</entry>
<entry name="ButtonTextColor" key="TextColor" type="Color" >
<label>Text color for the buttons.</label>
- <default code="true">KGlobalSettings::textColor()</default>
+ <default code="true">TDEGlobalSettings::textColor()</default>
</entry>
</group>
diff --git a/kicker/libkicker/panner.cpp b/kicker/libkicker/panner.cpp
index ddb990d8d..2027f19dd 100644
--- a/kicker/libkicker/panner.cpp
+++ b/kicker/libkicker/panner.cpp
@@ -42,7 +42,7 @@ Panner::Panner( TQWidget* parent, const char* name )
_cwidth(0), _cheight(0),
_cx(0), _cy(0)
{
- KGlobal::locale()->insertCatalogue("libkicker");
+ TDEGlobal::locale()->insertCatalogue("libkicker");
setBackgroundOrigin( AncestorOrigin );
_updateScrollButtonsTimer = new TQTimer(this);
diff --git a/kicker/libkicker/simplebutton.cpp b/kicker/libkicker/simplebutton.cpp
index 178277c25..87fd17200 100644
--- a/kicker/libkicker/simplebutton.cpp
+++ b/kicker/libkicker/simplebutton.cpp
@@ -172,7 +172,7 @@ void SimpleButton::slotSettingsChanged(int category)
bool changeCursor;
if (m_forceStandardCursor == FALSE)
- changeCursor = KGlobalSettings::changeCursorOverIcon();
+ changeCursor = TDEGlobalSettings::changeCursorOverIcon();
else
changeCursor = FALSE;
diff --git a/kicker/libkicker/panelbutton.cpp b/kicker/libkicker/panelbutton.cpp
index c862b09c5..3ecc19dfd 100644
--- a/kicker/libkicker/panelbutton.cpp
+++ b/kicker/libkicker/panelbutton.cpp
@@ -80,11 +80,11 @@ PanelButton::PanelButton( TQWidget* parent, const char* name, bool forceStandard
{
setBackgroundOrigin(AncestorOrigin);
setWFlags(TQt::WNoAutoErase);
- KGlobal::locale()->insertCatalogue("libkicker");
+ TDEGlobal::locale()->insertCatalogue("libkicker");
calculateIconSize();
setAcceptDrops(true);
- m_textColor = KGlobalSettings::textColor();
+ m_textColor = TDEGlobalSettings::textColor();
updateSettings(TDEApplication::SETTINGS_MOUSE);
@@ -108,7 +108,7 @@ void PanelButton::configure()
return;
}
- KConfigGroup tilesGroup( KGlobal::config(), "button_tiles" );
+ KConfigGroup tilesGroup( TDEGlobal::config(), "button_tiles" );
if( !tilesGroup.readBoolEntry( "Enable" + name + "Tiles", true ) ) {
setTile( TQString::null );
return;
@@ -171,7 +171,7 @@ TQImage PanelButton::loadTile(const TQString& tile,
name += state + ".png";
- TQImage tileImg(KGlobal::dirs()->findResource("tiles", name));
+ TQImage tileImg(TDEGlobal::dirs()->findResource("tiles", name));
// scale if size does not match exactly
if (!tileImg.isNull() && tileImg.size() != size)
@@ -225,7 +225,7 @@ void PanelButton::updateSettings(int category)
}
if (m_forceStandardCursor == FALSE)
- m_changeCursorOverItem = KGlobalSettings::changeCursorOverIcon();
+ m_changeCursorOverItem = TDEGlobalSettings::changeCursorOverIcon();
else
m_changeCursorOverItem = FALSE;
@@ -490,7 +490,7 @@ void PanelButton::mouseMoveEvent(TQMouseEvent *e)
TQPoint p(e->pos() - m_lastLeftMouseButtonPress);
if (p.manhattanLength() <= 16)
{
// KGlobalSettings::dndEventDelay() is not enough!
return;
}
@@ -781,7 +781,7 @@ int PanelButton::preferredIconSize(int proposed_size) const
{
// (re)calculates the icon sizes and report true if they have changed.
// Get sizes from icontheme. We assume they are sorted.
- KIconTheme *ith = KGlobal::iconLoader()->theme();
+ KIconTheme *ith = TDEGlobal::iconLoader()->theme();
if (!ith)
{
@@ -878,7 +878,7 @@ void PanelButton::loadTiles()
void PanelButton::loadIcons()
{
- KIconLoader * ldr = KGlobal::iconLoader();
+ KIconLoader * ldr = TDEGlobal::iconLoader();
TQString nm = m_iconName;
KIcon::States defaultState = isEnabled() ? KIcon::DefaultState :
KIcon::DisabledState;
@@ -490,7 +490,7 @@ void PanelButton::mouseMoveEvent(TQMouseEvent *e)
if (p.manhattanLength() <= 16)
{
- // KGlobalSettings::dndEventDelay() is not enough!
+ // TDEGlobalSettings::dndEventDelay() is not enough!
return;
}